@@ -24,8 +24,8 @@
  * SaMMAեԽ
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.14 $
- * $Date: 2010/12/11 02:04:50 $
+ * $Revision: 1.16 $
+ * $Date: 2013/09/03 03:11:11 $
  **********************************************************/
 
 include_once("../../initial");
@@ -41,521 +41,267 @@ include_once("lib/dglibsamma");
 *********************************************************/
 
 define("OPERATION", "եԽ");
+define("TMPLFILE", "samma/samma_admin_config.tmpl");
 
 /***********************************************************
- * 饹: ˥塼
+ * display_result()
+ *
+ * ֤ξ򥻥åȤ
+ *
+ * []
+ *      $tag  ֤
+ *
+ * [֤]
+ *       ʤ
  **********************************************************/
-Class my_page extends page {
+function display_result(&$tag) {
+    global $sesskey;
+    global $samma_conf;
+    global $logfacility;
+    global $db_types;
+    global $str_code;
 
-    /***********************************************************
-     * ܥǥɽʥС饤ɡ
-     **********************************************************/
-    function display_body() {
-        global $sesskey;
-        global $samma_conf;
-        global $logfacility;
-        global $db_types;
-        global $str_code;
+    /* ѥ */
+    $commandpass = "";
+    if (isset($samma_conf["commandpass"]) === TRUE && 
+              $samma_conf["commandpass"] != "") {
+        $commandpass = htmlspecialchars($samma_conf["commandpass"]);
+    }
+    $tag["<<COMMANDPASS>>"] = $commandpass;
 
-        /* ѥ */
-        $commandpass = "";
-        if (isset($samma_conf["commandpass"]) === TRUE && 
-                  $samma_conf["commandpass"] != "") {
-            $commandpass = htmlspecialchars($samma_conf["commandpass"]);
-        }
-
-        /* եƥ */
-        $html_log = "";
-        foreach ($logfacility as $log) {
-            $selected = "";
-            /* פ */
-            if (isset($samma_conf["syslogfacility"]) === TRUE &&
+    /* եƥ */
+    $html_log = "";
+    foreach ($logfacility as $log) {
+        $selected = "";
+        /* פ */
+        if (isset($samma_conf["syslogfacility"]) === TRUE &&
                   $samma_conf["syslogfacility"] != "") {
-                if ($log == $samma_conf["syslogfacility"]) {
-                    $selected = "selected";
-                } 
-            } else {
-                /* åȤƤʤϥǥե */
-                if ($log == "local0") {
-                    $selected = "selected";
-                }
+            if ($log == $samma_conf["syslogfacility"]) {
+                $selected = "selected";
+            } 
+        } else {
+            /* åȤƤʤϥǥե */
+            if ($log == "local0") {
+                $selected = "selected";
             }
-            $html_log .=<<<EOD
-            <option value="$log" $selected>$log
-EOD;
         }
+        $html_log .= "<option value=\"$log\"$selected>$log";
+        $tag["<<HTML_LOG>>"] = $html_log;
+    }
 
-        /* Ǽǥ쥯ȥ */
-        $encryptiontmpdir = "";
-        if (isset($samma_conf["encryptiontmpdir"]) === TRUE && 
-                  $samma_conf["encryptiontmpdir"] != "") {
-            $encryptiontmpdir = htmlspecialchars($samma_conf["encryptiontmpdir"]);
-        }
+    /* Ǽǥ쥯ȥ */
+    $encryptiontmpdir = "";
+    if (isset($samma_conf["encryptiontmpdir"]) === TRUE && 
+              $samma_conf["encryptiontmpdir"] != "") {
+        $encryptiontmpdir = htmlspecialchars($samma_conf["encryptiontmpdir"]);
+    }
+    $tag["<<ENCRYPTIONTMPDIR>>"] = $encryptiontmpdir;
 
-        /* zipޥɥѥ */
-        $zipcommand = "";
-        if (isset($samma_conf["zipcommand"]) === TRUE && 
-                  $samma_conf["zipcommand"] != "") {
-            $zipcommand = htmlspecialchars($samma_conf["zipcommand"]);
-        }
+    /* zipޥɥѥ */
+    $zipcommand = "";
+    if (isset($samma_conf["zipcommand"]) === TRUE && 
+              $samma_conf["zipcommand"] != "") {
+        $zipcommand = htmlspecialchars($samma_conf["zipcommand"]);
+    }
+    $tag["<<ZIPCOMMAND>>"] = $zipcommand;
 
-        /* zipޥɥץ */
-        $zipcommandopt = "";
-        if (isset($samma_conf["zipcommandopt"]) === TRUE && 
-                  $samma_conf["zipcommandopt"] != "") {
-            $zipcommandopt = htmlspecialchars($samma_conf["zipcommandopt"]);
-        }
+    /* zipޥɥץ */
+    $zipcommandopt = "";
+    if (isset($samma_conf["zipcommandopt"]) === TRUE && 
+              $samma_conf["zipcommandopt"] != "") {
+        $zipcommandopt = htmlspecialchars($samma_conf["zipcommandopt"]);
+    }
+    $tag["<<ZIPCOMMANDOPT>>"] = $zipcommandopt;
 
-        /* ɥᥤDB/ѥ */
-       $html_sender = "";
-        foreach ($db_types as $s_type) {
-            $s_file = "";
-            $type = "";
-            if (isset($samma_conf["senderdb"]) === TRUE &&
+    /* ɥᥤDB/ѥ */
+   $html_sender = "";
+    foreach ($db_types as $s_type) {
+        $s_file = "";
+        $type = "";
+        if (isset($samma_conf["senderdb"]) === TRUE &&
                   $samma_conf["senderdb"] != "") {
-                $send = explode(":", $samma_conf["senderdb"], 2);
-                $type = $send[0];
-                $s_file = htmlspecialchars($send[1]);
-            }
-            $selected = "";
-            /* פ */
-            if ($s_type == $type) {
-                    $selected = "selected";
-            }
-            $html_sender .=<<<EOD
-            <option value="$s_type" $selected>$s_type
-EOD;
+            $send = explode(":", $samma_conf["senderdb"], 2);
+            $type = $send[0];
+            $s_file = htmlspecialchars($send[1]);
         }
-            
-        /* DB/ѥ */
-        $html_rcpt = "";
-        foreach ($db_types as $r_type) {
-            $r_file = "";
-            $type = "";
-            if (isset($samma_conf["rcptdb"]) === TRUE &&
+        $selected = "";
+        /* פ */
+        if ($s_type == $type) {
+                $selected = "selected";
+        }
+        $html_sender .= "<option value=\"$s_type\" $selected>$s_type";
+        $tag["<<HTML_SENDER>>"] = $html_sender;
+    }
+    $tag["<<S_FILE>>"] = $s_file;
+    
+    /* DB/ѥ */
+    $html_rcpt = "";
+    foreach ($db_types as $r_type) {
+        $r_file = "";
+        $type = "";
+        if (isset($samma_conf["rcptdb"]) === TRUE &&
                   $samma_conf["rcptdb"] != "") {
-                $rcpt = explode(":", $samma_conf["rcptdb"], 2);
-                $type = $rcpt[0];
-                $r_file = htmlspecialchars($rcpt[1]);
-            }
-            $selected = "";
-            /* פ */
-            if ($r_type == $type) {
-                    $selected = "selected";
-            }
-            $html_rcpt .=<<<EOD
-            <option value="$r_type" $selected>$r_type
-EOD;
+            $rcpt = explode(":", $samma_conf["rcptdb"], 2);
+            $type = $rcpt[0];
+            $r_file = htmlspecialchars($rcpt[1]);
         }
-            
-        /* Υ᡼ƥץ졼ȥѥ */
-        $templatepath = "";
-        if (isset($samma_conf["templatepath"]) === TRUE && 
-                  $samma_conf["templatepath"] != "") {
-            $templatepath = htmlspecialchars($samma_conf["templatepath"]);
+        $selected = "";
+        /* פ */
+        if ($r_type == $type) {
+                $selected = "selected";
         }
-
-        /* sendmailޥɥѥ/ץ */
-        $sendmailcommand = "";
-        if (isset($samma_conf["sendmailcommand"]) === TRUE && 
-                  $samma_conf["sendmailcommand"] != "") {
-            $sendmailcommand = htmlspecialchars($samma_conf["sendmailcommand"]);
-        }
-
-        /* Ź沽ZIPեեޥå */
-        $zipfilename = "";
-        if (isset($samma_conf["zipfilename"]) === TRUE && 
-                  $samma_conf["zipfilename"] != "") {
-            $zipfilename = htmlspecialchars($samma_conf["zipfilename"]);
-        }
-
-        /* ¸ǥ쥯ȥ */
-        $mailsavetmpdir = "";
-        if (isset($samma_conf["mailsavetmpdir"]) === TRUE && 
-                  $samma_conf["mailsavetmpdir"] != "") {
-            $mailsavetmpdir = htmlspecialchars($samma_conf["mailsavetmpdir"]);
-        }
-
-        /* ѥʸ */
-        $passwordlength = "";
-        if (isset($samma_conf["passwordlength"]) === TRUE && 
-                  $samma_conf["passwordlength"] != "") {
-            $passwordlength = htmlspecialchars($samma_conf["passwordlength"]);
-        }
-
-        /* ե̾Ѵʸ */
-        $html_strcode = "";
-        foreach ($str_code as $code) {
-            $selected = "";
-            /* פ */
-            if (isset($samma_conf["strcode"]) === TRUE &&
-                  $samma_conf["strcode"] != "") {
-                if ($code == $samma_conf["strcode"]) {
-                    $selected = "selected";
-                } 
-            } else {
-                /* åȤƤʤϥǥե */
-                if ($code == DEF_CODE) {
-                    $selected = "selected";
-                }
-            }
-            $html_strcode .=<<<EOD
-            <option value="$code" $selected>$code
-EOD;
-        }
-
-        /* ǥեȽ */
-        $enc_on = "";
-        $enc_off = "checked";
-        if (isset($samma_conf["defaultencryption"]) === TRUE && 
-                  $samma_conf["defaultencryption"] != "") {
-            if ($samma_conf["defaultencryption"] == "yes") {
-                $enc_on = "checked";
-                $enc_off = "";
-            }
-        }
-
-        /* ǥեȥѥ */
-        $defaultpassword = "";
-        if (isset($samma_conf["defaultpassword"]) === TRUE && 
-                  $samma_conf["defaultpassword"] != "") {
-            $defaultpassword = htmlspecialchars($samma_conf["defaultpassword"]);
-        }
-
-        /* 桼 */
-        $user_on = "";
-        $user_off = "checked";
-        $disabled = "disabled";
-        if (isset($samma_conf["userpolicy"]) === TRUE && 
-                  $samma_conf["userpolicy"] != "") {
-            if ($samma_conf["userpolicy"] == "yes") {
-                $user_on = "checked";
-                $user_off = "";
-                $disabled = "";
-            }
-        }
-
-        /* LDAPСݡ */
-        $ldapserver = "";
-        $ldapport = "";
-        if (isset($samma_conf["ldapuri"]) === TRUE && 
-                  $samma_conf["ldapuri"] != "") {
-            /* ://פڤʬ */
-            $uri = explode("://", $samma_conf["ldapuri"]);
-            /* IPȥݡȤڤʬ */
-            $serverdata = explode(":", $uri[1]);
-            /* Ǽ(ݡȤΡ/פ) */
-            $ldapserver = htmlspecialchars($serverdata[0]);
-            $ldapport = htmlspecialchars(rtrim($serverdata[1], "/"));
-        }
-
-        /* LDAP١DN */
-        $ldapbasedn = "";
-        if (isset($samma_conf["ldapbasedn"]) === TRUE && 
-                  $samma_conf["ldapbasedn"] != "") {
-            $ldapbasedn = htmlspecialchars($samma_conf["ldapbasedn"]);
-        }
-
-        /* LDAPХDN */
-        $ldapbinddn = "";
-        if (isset($samma_conf["ldapbinddn"]) === TRUE && 
-                  $samma_conf["ldapbinddn"] != "") {
-            $ldapbinddn = htmlspecialchars($samma_conf["ldapbinddn"]);
-        }
-
-        /* LDAPХɥѥ */
-        $ldapbindpassword = "";
-        if (isset($samma_conf["ldapbindpassword"]) === TRUE && 
-                  $samma_conf["ldapbindpassword"] != "") {
-            $ldapbindpassword = htmlspecialchars($samma_conf["ldapbindpassword"]);
-        }
-
-        /* LDAPե륿 */
-        $ldapfilter = "";
-        if (isset($samma_conf["ldapfilter"]) === TRUE && 
-                  $samma_conf["ldapfilter"] != "") {
-            $ldapfilter = htmlspecialchars($samma_conf["ldapfilter"]);
-        }
-
-        print<<<EOD
-
-<script type="text/javascript">
-<!--
-function ldap_disable(flg) {
-    if (flg == "no") {
-        document.config.ldapserver.disabled = true;
-        document.config.ldapport.disabled = true;
-        document.config.ldapbasedn.disabled = true;
-        document.config.ldapbinddn.disabled = true;
-        document.config.ldapbindpassword.disabled = true;
-        document.config.ldapfilter.disabled = true;
-    } else {
-        document.config.ldapserver.disabled = false;
-        document.config.ldapport.disabled = false;
-        document.config.ldapbasedn.disabled = false;
-        document.config.ldapbinddn.disabled = false;
-        document.config.ldapbindpassword.disabled = false;
-        document.config.ldapfilter.disabled = false;
+        $html_rcpt .= "<option value=\"$r_type\" $selected>$r_type";
+        $tag["<<HTML_RCPT>>"] = $html_rcpt;
     }
+    $tag["<<R_FILE>>"] = $r_file;
+        
+    /* Υ᡼ƥץ졼ȥѥ */
+    $templatepath = "";
+    if (isset($samma_conf["templatepath"]) === TRUE && 
+              $samma_conf["templatepath"] != "") {
+        $templatepath = htmlspecialchars($samma_conf["templatepath"]);
+    }
+    $tag["<<TEMPLATEPATH>>"] = $templatepath;
+
+    /* sendmailޥɥѥ/ץ */
+    $sendmailcommand = "";
+    if (isset($samma_conf["sendmailcommand"]) === TRUE && 
+              $samma_conf["sendmailcommand"] != "") {
+        $sendmailcommand = htmlspecialchars($samma_conf["sendmailcommand"]);
+    }
+    $tag["<<SENDMAILCOMMAND>>"] = $sendmailcommand;
+
+    /* Ź沽ZIPեեޥå */
+    $zipfilename = "";
+    if (isset($samma_conf["zipfilename"]) === TRUE && 
+              $samma_conf["zipfilename"] != "") {
+        $zipfilename = htmlspecialchars($samma_conf["zipfilename"]);
+    }
+    $tag["<<ZIPFILENAME>>"] = $zipfilename;
+
+    /* ¸ǥ쥯ȥ */
+    $mailsavetmpdir = "";
+    if (isset($samma_conf["mailsavetmpdir"]) === TRUE && 
+              $samma_conf["mailsavetmpdir"] != "") {
+        $mailsavetmpdir = htmlspecialchars($samma_conf["mailsavetmpdir"]);
+    }
+    $tag["<<MAILSAVETMPDIR>>"] = $mailsavetmpdir;
+
+    /* ѥʸ */
+    $passwordlength = "";
+    if (isset($samma_conf["passwordlength"]) === TRUE && 
+              $samma_conf["passwordlength"] != "") {
+        $passwordlength = htmlspecialchars($samma_conf["passwordlength"]);
+    }
+    $tag["<<PASSWORDLENGTH>>"] = $passwordlength;
+
+    /* ե̾Ѵʸ */
+    $html_strcode = "";
+    foreach ($str_code as $code) {
+        $selected = "";
+        /* פ */
+        if (isset($samma_conf["strcode"]) === TRUE &&
+              $samma_conf["strcode"] != "") {
+            if ($code == $samma_conf["strcode"]) {
+                $selected = "selected";
+            } 
+        } else {
+            /* åȤƤʤϥǥե */
+            if ($code == DEF_CODE) {
+                $selected = "selected";
+            }
+        }
+        $html_strcode .= "<option value=\"$code\" $selected>$code";
+        $tag["<<HTML_STRCODE>>"] = $html_strcode;
+    }
+
+    /* ǥեȽ */
+    $enc_on = "";
+    $enc_off = "checked";
+    if (isset($samma_conf["defaultencryption"]) === TRUE && 
+              $samma_conf["defaultencryption"] != "") {
+        if ($samma_conf["defaultencryption"] == "yes") {
+            $enc_on = "checked";
+            $enc_off = "";
+        }
+    }
+    $tag["<<ENC_ON>>"] = $enc_on;
+    $tag["<<ENC_OFF>>"] = $enc_off;
+
+    /* ǥեȥѥ */
+    $defaultpassword = "";
+    if (isset($samma_conf["defaultpassword"]) === TRUE && 
+              $samma_conf["defaultpassword"] != "") {
+        $defaultpassword = htmlspecialchars($samma_conf["defaultpassword"]);
+    }
+    $tag["<<DEFAULTPASSWORD>>"] = $defaultpassword;
+
+    /* 桼 */
+    $user_on = "";
+    $user_off = "checked";
+    $disabled = "disabled";
+    if (isset($samma_conf["userpolicy"]) === TRUE && 
+              $samma_conf["userpolicy"] != "") {
+        if ($samma_conf["userpolicy"] == "yes") {
+            $user_on = "checked";
+            $user_off = "";
+            $disabled = "";
+        }
+    }
+    $tag["<<USER_ON>>"] = $user_on;
+    $tag["<<USER_OFF>>"] = $user_off;
+    $tag["<<DISABLED>>"] = $disabled;
+
+    /* LDAPСݡ */
+    $ldapserver = "";
+    $ldapport = "";
+    if (isset($samma_conf["ldapuri"]) === TRUE && 
+              $samma_conf["ldapuri"] != "") {
+        /* ://פڤʬ */
+        $uri = explode("://", $samma_conf["ldapuri"]);
+        /* IPȥݡȤڤʬ */
+        $serverdata = explode(":", $uri[1]);
+        /* Ǽ(ݡȤΡ/פ) */
+        $ldapserver = htmlspecialchars($serverdata[0]);
+        $ldapport = htmlspecialchars(rtrim($serverdata[1], "/"));
+    }
+    $tag["<<LDAPSERVER>>"] = $ldapserver;
+    $tag["<<LDAPPORT>>"] = $ldapport;
+
+    /* LDAP١DN */
+    $ldapbasedn = "";
+    if (isset($samma_conf["ldapbasedn"]) === TRUE && 
+              $samma_conf["ldapbasedn"] != "") {
+        $ldapbasedn = htmlspecialchars($samma_conf["ldapbasedn"]);
+    }
+    $tag["<<LDAPBASEDN>>"] = $ldapbasedn;
+
+    /* LDAPХDN */
+    $ldapbinddn = "";
+    if (isset($samma_conf["ldapbinddn"]) === TRUE && 
+              $samma_conf["ldapbinddn"] != "") {
+        $ldapbinddn = htmlspecialchars($samma_conf["ldapbinddn"]);
+    }
+    $tag["<<LDAPBINDDN>>"] = $ldapbinddn;
+
+    /* LDAPХɥѥ */
+    $ldapbindpassword = "";
+    if (isset($samma_conf["ldapbindpassword"]) === TRUE && 
+              $samma_conf["ldapbindpassword"] != "") {
+        $ldapbindpassword = htmlspecialchars($samma_conf["ldapbindpassword"]);
+    }
+    $tag["<<LDAPBINDPASSWORD>>"] = $ldapbindpassword;
+
+    /* LDAPե륿 */
+    $ldapfilter = "";
+    if (isset($samma_conf["ldapfilter"]) === TRUE && 
+              $samma_conf["ldapfilter"] != "") {
+        $ldapfilter = htmlspecialchars($samma_conf["ldapfilter"]);
+    }
+    $tag["<<LDAPFILTER>>"] = $ldapfilter;
+
+    return TRUE;
 }
-// -->
-</script>
-<form method="POST" action="index.php" name="config">
-  <table class="table">
-
-    <tbody>
-      <tr>
-        <td class="key1">Ϣѥѥ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-          <input type="text" size="30" maxlength="20" name="commandpass" value="$commandpass">
-          </td>
-
-          <td class="value_must2">
-          <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">Syslogեƥ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <select name="syslogfacility">
-$html_log
-            </select>
-          </td>
-          <td class="value_must2">
-            <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">Ǽǥ쥯ȥ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <input type="text" size="60" maxlength="256" name="encryptiontmpdir" value="$encryptiontmpdir">
-          </td>
-          <td class="value_must2">
-            <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">zipޥɥѥ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <input type="text" size="60" maxlength="256" name="zipcommand" value="$zipcommand">
-          </td>
-          <td class="value_must2"><span class="must_input">*</span>
-          </td>
-          </table> 
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">zipޥɥץ</td>
-        <td class="value">
-          <input type="text" size="60" maxlength="256" name="zipcommandopt" value="$zipcommandopt">
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">ɥᥤDB/ѥ</td>
-        <td class="value">
-          <select name="sd_dbtype">
-$html_sender
-          </select>
-          <input type="text" size="48" maxlength="256" name="sd_dbfile" value="$s_file">
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">DB/ѥ</td>
-
-        <td class="value">
-          <select name="rp_dbtype">
-$html_rcpt
-          </select>
-          <input type="text" size="48" maxlength="256" name="rp_dbfile" value="$r_file">
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">Υ᡼ƥץ졼ȥѥ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <input type="text" size="60" maxlength="256" name="templatepath" value="$templatepath">
-          </td>
-          <td class="value_must2">
-            <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">sendmailޥɥѥ/ץ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <input type="text" size="60" maxlength="256" name="sendmailcommand" value="$sendmailcommand">
-          </td>
-          <td class="value_must2">
-            <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">Ź沽ZIPեեޥå</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <input type="text" size="60" maxlength="256" name="zipfilename" value="$zipfilename">
-          </td>
-          <td class="value_must2">
-            <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">¸ǥ쥯ȥ</td>
-        <td class="value">
-          <table>
-          <td class="value_must1">
-            <input type="text" size="60" maxlength="256" name="mailsavetmpdir" value="$mailsavetmpdir">
-          </td>
-          <td class="value_must2">
-              <span class="must_input">*</span>
-          </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">ѥʸ</td>
-
-        <td class="value">
-          <input type="text" size="5" maxlength="2" name="passwordlength" value="$passwordlength">
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">ե̾Ѵʸ</td>
-        <td class="value">
-          <table>
-            <td class ="value_must1">
-              <select name="strcode">
-$html_strcode
-              </select>
-            </td>
-            <td class="value_must2">
-              <span class="must_input">*</span>
-
-            </td>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">ǥեȽ</td>
-        <td class="value">
-          <table>
-            <tr>
-              <td class="value_must1"><input type="radio" name="defaultencryption" value="yes" $enc_on>Ź沽</td>
-              <td rowspan=2 class="value_must2">
-              <span class="must_input">*</span>
-             </td>
-            </tr>
-            <tr>
-              <td class="value_must1">
-              <input type="radio" name="defaultencryption" value="no" $enc_off>Ź沽ʤ
-              </td>
-            </tr>
-          </table>
-
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">ǥեȥѥ</td>
-        <td class="value">
-          <input type="text" size="30" maxlength="20" name="defaultpassword" value="$defaultpassword">
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">桼</td>
-        <td class="value">
-          <table>
-            <tr>
-              <td class="value_must1"><input type="radio" name="userpolicy" value="yes" $user_on onClick="ldap_disable('yes');">ͭ</td>
-             <td rowspan=2 class="value_must2">
-              <span class="must_input">*</span>
-             </td>
-            </tr>
-            <tr>
-              <td class="value_must1">
-              <input type="radio" name="userpolicy" value="no" $user_off onClick="ldap_disable('no');">̵
-              </td>
-            </tr>
-          </table>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">LDAP</td>
-
-        <td class="value">
-          <input type="text" size="60" maxlength="15" name="ldapserver" value="$ldapserver" $disabled>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">LDAPݡ</td>
-        <td class="value">
-          <input type="text" size="60" maxlength="6" name="ldapport" value="$ldapport" $disabled>
-
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">LDAP١DN</td>
-        <td class="value">
-          <input type="text" size="60" maxlength="256" name="ldapbasedn" value="$ldapbasedn" $disabled>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">LDAPХDN</td>
-        <td class="value">
-          <input type="text" size="60" maxlength="256" name="ldapbinddn" value="$ldapbinddn" $disabled>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">LDAPХɥѥ</td>
-
-        <td class="value">
-          <input type="text" size="30" maxlength="20" name="ldapbindpassword" value="$ldapbindpassword" $disabled>
-        </td>
-      </tr>
-      <tr>
-        <td class="key1">LDAPե륿</td>
-
-        <td class="value">
-          <input type="text" size="60" maxlength="128" name="ldapfilter" value="$ldapfilter" $disabled>
-        </td>
-      </tr>
-    </tbody>
-
-  </table>
-<div><span class="must_input">*</span>ɬܹܤǤ</div>
-
-  <br>
-  <input type="submit" name="mod" value="" class="mod_btn">
-  <input type="submit" name="cancel" value="" class="cancel_btn">
-  <input type="hidden" name="sk" value="$sesskey">
-
-
-</form>
-EOD;
-    }
-};
 
 /*********************************************************
  * check_conf_data
@@ -643,7 +389,6 @@ function check_conf_data(&$data)
             $data["sd_dbfile"] .= ".db";
             $data["senderdb"] .= ".db";
         }
-
         /* å(ʤк) */
         if (check_db($data["sd_dbfile"], $data["sd_dbtype"]) === FALSE) {
             $err_msg = "ɥᥤ" . $err_msg;
@@ -878,6 +623,7 @@ function check_db($db_file, $db_type)
     } else {
         $command = sprintf(CONFIRM_DB, $db_type, escapeshellcmd($db_file));
         $ret = system($command, $result);
+
         if ($result != 0) {
             $err_msg = "DBǤ";
             return FALSE;
@@ -887,7 +633,6 @@ function check_db($db_file, $db_type)
             return FALSE;
         }
     }
-
     return TRUE;
 
 }
@@ -1111,23 +856,25 @@ function make_def_tmpl($filename)
 /***********************************************************
  * 
  **********************************************************/
+/* ͤν */
+$tag = array();
 
-/* 󥹥󥹺 */
-$pg = new my_page();
+/* å󥭡ѿ */
+if (isset ($_POST["sk"]) === TRUE) {
+    $sesskey = $_POST["sk"];
+}
 
 /* ե륿ִեɹåΥå */
 $ret = init();
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
 /* SaMMAեɹ */
 $ret = read_samma_conf($web_conf["postldapadmin"]["sammaconf"]);
 if ($ret === FALSE) {
-    $sys_err = TRUE;
-    $pg->display(NULL);
+    syserr_display();
     exit (1);
 }
 
@@ -1173,8 +920,18 @@ if (isset($_POST["mod"]) === TRUE) {
 /***********************************************************
  * ɽ
  **********************************************************/
+/* ̤Υ */
+set_tag_common($tag);
+
+/* ̤֤ */
+display_result($tag);
 
 /* ڡν */
-$pg->display(CONTENT);
+$ret = display(TMPLFILE, $tag, array(), "", "");
+if ($ret === FALSE) {
+    result_log($log_msg, LOG_ERR);
+    syserr_display();
+    exit(1);
+}
 
 ?>
